/*
Code by @Dimzcraft.
(c) Don't use any Code without permission
*/
import { EquipmentSlot, world, system } from '@minecraft/server';
import itemIdList from './item_id';

const armorSlots = [EquipmentSlot.Head, EquipmentSlot.Chest, EquipmentSlot.Legs, EquipmentSlot.Feet, EquipmentSlot.Offhand];

function DurabilityArmorViewer(player) {
  const equipment = player.getComponent('equippable');
  
  let title = '§d§m§z§d§a§v§r§f:';
  let subtitle = '§d§m§z§d§a§v§r§f:';

  for (const slot of armorSlots) {
    const item = equipment.getEquipment(slot);
    const itemId = item ? itemIdList[item.typeId] || '1403' : '1403';
    title += `${itemId}`;
  
    if (item && item.hasComponent("minecraft:durability")) {
      const maxDurability = item.getComponent('durability').maxDurability;
      const damage = item.getComponent('durability').damage;
      const durabilityPercent = Math.floor((maxDurability - damage) / maxDurability * 1000);
      subtitle += `${(durabilityPercent).toString().padStart(4, '_')}`;
      
    } else {
      subtitle += `1404`;
    }
    
    if (slot === EquipmentSlot.Offhand && item) {
      const itemCount = item.amount || 1;
      subtitle += `${(itemCount).toString().padStart(4, '_')}`;
    }
  };
 
  // console.error(title);
  // console.error(subtitle);
  player.onScreenDisplay.setTitle(title, { stayDuration: 1, fadeInDuration: 0, fadeOutDuration: 0, subtitle });
};


world.afterEvents.entityHurt.subscribe(function (event) {
  if (event.hurtEntity.typeId == "minecraft:player") {
    DurabilityArmorViewer(event.hurtEntity);
  }
});

world.afterEvents.itemUse.subscribe((event) => {
  const { source: player, itemStack: item } = event
  if (item.getComponent("minecraft:durability")?.isValid()) {
    DurabilityArmorViewer(player);
  }
});

system.runInterval(() => {
  for (const player of world.getPlayers()) {
    DurabilityArmorViewer(player);
  }
}, 30);